@@ -2,13 +2,13 @@ use strict;
 use warnings;
 package Email::MIME::Encode;
 # ABSTRACT: a private helper for MIME header encoding
-$Email::MIME::Encode::VERSION = '1.938'; # TRIAL
+$Email::MIME::Encode::VERSION = '1.939'; # TRIAL
 use Email::Address;
 use Encode ();
 use MIME::Base64();
 
 my %address_list_headers = map { $_ => undef } qw(from sender reply-to to cc bcc);
-my %no_mime_headers = map { $_ => undef } qw(date message-id in-reply-to references);
+my %no_mime_headers = map { $_ => undef } qw(date message-id in-reply-to references downgraded-message-id downgraded-in-reply-to downgraded-references);
 
 sub maybe_mime_encode_header {
     my ($header, $val, $charset) = @_;
@@ -103,6 +103,30 @@ sub mime_encode {
     return join q{ }, @result;
 }
 
+sub maybe_mime_decode_header {
+    my ($header, $val) = @_;
+
+    $header = lc $header;
+    $header =~ s/^resent-//i;
+
+    return $val
+        if exists $no_mime_headers{$header};
+
+    return mime_decode($val);
+}
+
+sub mime_decode {
+    my ($text) = @_;
+    return undef unless defined $text;
+
+    # The eval is to cope with unknown encodings, like Latin-62, or other
+    # nonsense that gets put in there by spammers and weirdos
+    # -- rjbs, 2014-12-04
+    local $@;
+    my $result = eval { Encode::decode("MIME-Header", $text) };
+    return defined $result ? $result : $text;
+}
+
 1;
 
 __END__
@@ -117,7 +141,7 @@ Email::MIME::Encode - a private helper for MIME header encoding
 
 =head1 VERSION
 
-version 1.938
+version 1.939
 
 =head1 AUTHORS
 
